:mod:`art.defences.postprocessor`
=================================
.. automodule:: art.defences.postprocessor

Base Class Postprocessor
------------------------
.. autoclass:: Postprocessor
   :members:
   :special-members:

Class Labels
------------
.. autoclass:: ClassLabels
   :members:
   :special-members:

Gaussian Noise
--------------
.. autoclass:: GaussianNoise
   :members:
   :special-members:

High Confidence
---------------
.. autoclass:: HighConfidence
   :members:
   :special-members:

Reverse Sigmoid
---------------
.. autoclass:: ReverseSigmoid
   :members:
   :special-members:

Rounded
-------
.. autoclass:: Rounded
   :members:
   :special-members:
